netapp_ontap.models.volume_clone API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_clone`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeCloneSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeClone object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `has_flexclone: bool GET`

    Specifies whether this volume is a parent of any FlexClone volume.

  `inherited_physical_used: Size GET`

    Inherited physical used from the clone's base snapshot.

  `inherited_savings: Size GET`

    Inherited savings from the clone's base snapshot.

  `is_flexclone: bool GET POST`

    Specifies if this volume is a normal FlexVol volume or FlexClone volume. This field needs to be set when creating a FlexClone volume. Valid in POST.

  `lun_name: str GET POST`

    This optional parameter specifies the name of a LUN that will be non-disruptively migrated to the newly created FlexClone volume. If not specified, no LUNs are migrated.

  `parent_snapshot: Snapshot GET POST PATCH`

    The parent_snapshot field of the volume_clone.

  `parent_svm: Svm GET POST`

    The parent_svm field of the volume_clone.

  `parent_volume: Volume GET POST`

    The parent_volume field of the volume_clone.

  `qtree_name: str GET POST`

    This optional parameter specifies the name of the qtree containing the LUN that will be non-disruptively migrated to the newly created FlexClone volume.

  `split_complete_percent: Size GET`

    Percentage of FlexClone volume blocks split from its parent volume.

  `split_estimate: Size GET`

    Space required by the containing-aggregate to split the FlexClone volume.

  `split_initiated: bool GET PATCH`

    This field is set when a split is executed on any FlexClone volume, that is when the FlexClone volume is split from its parent FlexVol volume. Setting this field initiates a split of a FlexClone volume from a FlexVol volume. Valid in PATCH.